@@ -1,6 +1,6 @@
-# $Id: encoding.pm,v 2.10 2012/08/05 23:08:49 dankogai Exp dankogai $
+# $Id: encoding.pm,v 2.12 2013/04/26 18:30:46 dankogai Exp dankogai $
 package encoding;
-our $VERSION = '2.6_01';
+our $VERSION = sprintf "%d.%02d", q$Revision: 2.12 $ =~ /(\d+)/g;
 
 use Encode;
 use strict;
@@ -102,6 +102,10 @@ sub _get_locale_encoding {
 }
 
 sub import {
+    if ($] >= 5.017) {
+	warnings::warnif("deprecated",
+			 "Use of the encoding pragma is deprecated")
+    }
     my $class = shift;
     my $name  = shift;
     if (!$name){
@@ -203,6 +207,19 @@ __END__
 
 encoding - allows you to write your script in non-ascii or non-utf8
 
+=head1 WARNING
+
+This module is deprecated under perl 5.18.  It uses a mechanism provided by
+perl that is deprecated under 5.18 and higher, and may be removed in a
+future version.
+
+The easiest and the best alternative is to write your script in UTF-8
+and declear:
+
+  use utf8; # not use encoding ':utf8';
+
+See L<perluniintro> and L<utf8> for details.
+
 =head1 SYNOPSIS
 
   use encoding "greek";  # Perl like Greek to you?
